import traceback

from django.db import transaction

# from core.utils.logging import logger


class BaseDataMigrationTask:
    def __init__(self, **kwargs):
        self.version = None

    def _run(self):
        raise NotImplementedError

    def run(self, **kwargs):
        if self.version is None:
            raise Exception(
                "Version not defined. Skipping running the data migration task."
            )

        transaction.set_autocommit(False)
        try:
            self._run()
        except Exception as e:
            # logger.info(
            #     f"Exception occurred while running the Data Migration task - {str(e)}"
            # )
            traceback.print_exc()
            transaction.rollback()
            transaction.set_autocommit(True)
            return False, str(e)
        else:
            transaction.commit()
            # logger.info("Transaction committed")
            transaction.set_autocommit(True)

        return True, None



import uuid

from django.db import models
from dm.constants import DataMigrationStatus


class DataMigrationExecution(models.Model):
    id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
    created_on = models.DateTimeField(auto_now_add=True)
    updated_on = models.DateTimeField(auto_now=True)
    task = models.CharField(max_length=500)
    execution_version = models.IntegerField()
    status = models.CharField(
        choices=DataMigrationStatus.choices(),
        default=DataMigrationStatus.IN_PROGRESS.value,
        max_length=100,
    )

    class Meta:
        unique_together = (("task", "execution_version"),)

    def __str__(self):
        return f"{self.task} - v{self.execution_version}"



from django.core.management.base import BaseCommand
from dm.managers.dm.runner import DataMigrationRunner


class Command(BaseCommand):
    def handle(self, *args, **options):
        runner = DataMigrationRunner()
        runner.run()



from setuptools import setup, find_packages

setup(
    name="django_dmf",
    version="0.0.5",
    packages=find_packages(),
    include_package_data=True,
    license_files=["LICENSE"],
    license="MIT",
    description="A Version Controlled Fully Managed Data Migration Framework for Django",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/shivamAthb/django_dmf",
    author="Shivam Sharma",
    author_email="shivam.sharma@helixbeat.com",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 4.1",
        "Framework :: Django :: 4.2",
        "Framework :: Django :: 5.0",
        "Framework :: Django :: 5.1",
        "Framework :: Django :: 5.2",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Topic :: Software Development :: Libraries",
    ],
    install_requires=["Django>=3.2", 'json-log-formatter'],
    python_requires=">=3.7",
)



# Generated by Django 5.2.1 on 2025-06-21 15:01

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="DataMigrationExecution",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("updated_on", models.DateTimeField(auto_now=True)),
                ("task", models.CharField(max_length=500)),
                ("execution_version", models.IntegerField()),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("IN_PROGRESS", "IN_PROGRESS"),
                            ("FAILED", "FAILED"),
                            ("COMPLETED", "COMPLETED"),
                        ],
                        default="IN_PROGRESS",
                        max_length=100,
                    ),
                ),
            ],
            options={
                "unique_together": {("task", "execution_version")},
            },
        ),
    ]



from dm.tasks.dm.base import BaseDataMigrationTask
from dmf_test_app.managers.switch import FeatureSwitchManager


class FeatureSwitchDataMigrationTask(BaseDataMigrationTask):
    def __init__(self, **kwargs):
        super(FeatureSwitchDataMigrationTask, self).__init__(**kwargs)
        self.version = 2

    def _run(self):
        FeatureSwitchManager.seed_switches()



import uuid

from django.db import models


class FeatureSwitch(models.Model):
    id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
    created_on = models.DateTimeField(auto_now_add=True)
    updated_on = models.DateTimeField(auto_now=True)
    name = models.CharField(max_length=500, unique=True)
    description = models.TextField(null=True, blank=True)
    active = models.BooleanField(default=True)

    def __str__(self):
        return self.name



import csv

from dmf_test_app.constants import FEATURE_SWITCHES_FILE_PATH
from dmf_test_app.models import FeatureSwitch


class FeatureSwitchManager:
    @classmethod
    def seed_switches(cls):
        print("Loading all switches...")
        switches = list(csv.DictReader(open(FEATURE_SWITCHES_FILE_PATH)))
        for switch in switches:
            name = switch["name"]
            FeatureSwitch.objects.update_or_create(name=name, defaults=switch)

        print("Loaded all Switches.")
